@@ -9,7 +9,7 @@ import (
 	"strconv"
 	"testing"
 
-	searchv1alpha1 "github.com/stolostron/search-operator/api/v1alpha1"
+	searchv1alpha1 "github.com/open-cluster-management/search-operator/api/v1alpha1"
 	"github.com/stretchr/testify/assert"
 	appv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -35,6 +35,7 @@ type testSetup struct {
 	podWithOutPVC         *corev1.Pod
 	unSchedulablePod      *corev1.Pod
 	customizationCR       *searchv1alpha1.SearchCustomization
+	context               context.Context
 }
 
 func commonSetup() testSetup {
@@ -91,7 +92,8 @@ func commonSetup() testSetup {
 		podWithPVC:            fakePodWithPVC,
 		podWithOutPVC:         fakePodWithOutPVC,
 		unSchedulablePod:      fakeUnschedulablePod,
-		customizationCR:       fakeSearchCustCR}
+		customizationCR:       fakeSearchCustCR,
+		context:               context.TODO()}
 	return testSetup
 }
 
@@ -101,7 +103,7 @@ func Test_searchOperatorNotFound(t *testing.T) {
 	client := fake.NewFakeClientWithScheme(testSetup.scheme)
 	nilSearchOperator := SearchOperatorReconciler{client, log, testSetup.scheme}
 
-	_, err := nilSearchOperator.Reconcile(req)
+	_, err := nilSearchOperator.Reconcile(testSetup.context, req)
 	assert.Nil(t, err, "Expected Reconcile Error to be Nil. Got error: %v", err)
 
 	instance := &searchv1alpha1.SearchOperator{}
@@ -115,7 +117,7 @@ func Test_secretCreatedWithOwnerRef(t *testing.T) {
 	client := fake.NewFakeClientWithScheme(testSetup.scheme, testSetup.srchOperator)
 	nilSearchOperator := SearchOperatorReconciler{client, log, testSetup.scheme}
 
-	_, err := nilSearchOperator.Reconcile(testSetup.request)
+	_, err := nilSearchOperator.Reconcile(testSetup.context, testSetup.request)
 
 	found := &corev1.Secret{}
 	err = client.Get(context.TODO(), types.NamespacedName{Name: testSecret.Name, Namespace: testSecret.Namespace}, found)
@@ -141,7 +143,7 @@ func Test_secretAlreadyExists(t *testing.T) {
 	client := fake.NewFakeClientWithScheme(testSetup.scheme, testSetup.srchOperator, testSecret)
 	nilSearchOperator := SearchOperatorReconciler{client, log, testSetup.scheme}
 
-	_, err := nilSearchOperator.Reconcile(testSetup.request)
+	_, err := nilSearchOperator.Reconcile(testSetup.context, testSetup.request)
 
 	found := &corev1.Secret{}
 	err = client.Get(context.TODO(), types.NamespacedName{Name: testSecret.Name, Namespace: testSecret.Namespace}, found)
@@ -159,7 +161,7 @@ func Test_EmptyDirStatefulsetCreatedWithOwnerRef(t *testing.T) {
 	nilSearchOperator := SearchOperatorReconciler{client, log, testSetup.scheme}
 	var err error
 
-	_, err = nilSearchOperator.Reconcile(testSetup.request)
+	_, err = nilSearchOperator.Reconcile(testSetup.context, testSetup.request)
 
 	foundStatefulset := &appv1.StatefulSet{}
 	err = client.Get(context.TODO(), types.NamespacedName{Name: testSetup.statefulsetWithOutPVC.Name, Namespace: testSetup.statefulsetWithOutPVC.Namespace}, foundStatefulset)
@@ -191,9 +193,9 @@ func Test_StatefulsetWithNoPersistenceStatus(t *testing.T) {
 	testSetup.customizationCR.Spec.Persistence = &persistence
 	err = client.Update(context.TODO(), testSetup.customizationCR)
 
-	_, err = nilSearchOperator.Reconcile(testSetup.request)
+	_, err = nilSearchOperator.Reconcile(testSetup.context, testSetup.request)
 	//Calling reconcile again to check if shorter path with 1 sec wait time is used the second time
-	_, err = nilSearchOperator.Reconcile(testSetup.request)
+	_, err = nilSearchOperator.Reconcile(testSetup.context, testSetup.request)
 	err = client.Get(context.TODO(), testSetup.request.NamespacedName, instance)
 
 	assert.Nil(t, err, "Expected searchoperator to be found with no error. Got error: %v", err)
@@ -214,9 +216,9 @@ func Test_StatefulsetWithPVC(t *testing.T) {
 	assert.Nil(t, err, "Expected search Operator to be created. Got error: %v", err)
 
 	//Persistence is enabled by default in search operator
-	_, err = nilSearchOperator.Reconcile(req)
+	_, err = nilSearchOperator.Reconcile(testSetup.context, req)
 	//Calling reconcile again to check if shorter path with 1 sec wait time is used the second time
-	_, err = nilSearchOperator.Reconcile(req)
+	_, err = nilSearchOperator.Reconcile(testSetup.context, req)
 	assert.Nil(t, err, "Expected search Operator reconcile to complete successfully. Got error: %v", err)
 
 	err = client.Get(context.TODO(), req.NamespacedName, instance)
@@ -254,7 +256,7 @@ func Test_FailSettingupWithPVC(t *testing.T) {
 	testSetup.customizationCR.Spec.Persistence = &persistence
 	err = client.Create(context.TODO(), testSetup.customizationCR)
 
-	_, err = nilSearchOperator.Reconcile(req)
+	_, err = nilSearchOperator.Reconcile(testSetup.context, req)
 	assert.NotNil(t, err, "Expected Reconcile error to be not nil. Got nil.")
 
 	err = client.Get(context.TODO(), req.NamespacedName, instance)
@@ -282,7 +284,7 @@ func Test_UnschedulablePodWithPersistence(t *testing.T) {
 	assert.Nil(t, err, "Expected search Operator to be created. Got error: %v", err)
 
 	//Persistence is enabled by default in operator - this should cause statefulset to fall back to empty dir since we don't have PVC
-	_, err = nilSearchOperator.Reconcile(req)
+	_, err = nilSearchOperator.Reconcile(testSetup.context, req)
 	assert.NotNil(t, err, "Expected Reconcile error to be not nil. Got nil.")
 	assert.Equal(t, "Redisgraph Pod not running", err.Error(), "Expected Redisgraph Pod not running error. Got %v", err)
 
@@ -312,7 +314,7 @@ func Test_UnschedulablePodWithOutPersistence(t *testing.T) {
 	persistence := false
 	testSetup.customizationCR.Spec.Persistence = &persistence
 	err = client.Update(context.TODO(), testSetup.customizationCR)
-	_, err = nilSearchOperator.Reconcile(req)
+	_, err = nilSearchOperator.Reconcile(testSetup.context, req)
 
 	assert.NotNil(t, err, "Expected Reconcile error to be not nil. Got nil.")
 	assert.Equal(t, "Redisgraph Pod not running", err.Error(), "Expected Redisgraph Pod not running error. Got %v", err)
@@ -337,7 +339,7 @@ func Test_DoNotDeployRedisPod(t *testing.T) {
 	err = client.Get(context.TODO(), req.NamespacedName, instance)
 	assert.Nil(t, err, "Expected search Operator to be created. Got error: %v", err)
 
-	_, err = nilSearchOperator.Reconcile(req)
+	_, err = nilSearchOperator.Reconcile(testSetup.context, req)
 	assert.Nil(t, err, "Expected search Operator reconcile to complete successfully. Got error: %v", err)
 
 	err = client.Get(context.TODO(), req.NamespacedName, instance)
@@ -371,7 +373,7 @@ func Test_UnschedulablePodWithDisAllowDegradedMode(t *testing.T) {
 	persistence := true
 	testSetup.customizationCR.Spec.Persistence = &persistence
 	err = client.Update(context.TODO(), testSetup.customizationCR)
-	_, err = nilSearchOperator.Reconcile(req)
+	_, err = nilSearchOperator.Reconcile(testSetup.context, req)
 
 	assert.NotNil(t, err, "Expected Reconcile error to be not nil. Got nil.")
 	assert.Equal(t, "Redisgraph Pod not running", err.Error(), "Expected Redisgraph Pod not running error. Got %v", err)
@@ -457,7 +459,7 @@ func createFakeRedisGraphPod(namespace string, persistence, schedulable bool) *c
 	labels := map[string]string{}
 	labels["app"] = appName
 	labels["component"] = component
-	image := "quay.io/stolostron/search-operator:latest"
+	image := "quay.io/open-cluster-management/search-operator:latest"
 	containerStatuses := []corev1.ContainerStatus{}
 	containerStatus := corev1.ContainerStatus{Ready: true}
 	containerStatuses = append(containerStatuses, containerStatus)
